# -*- coding: utf-8 -*-
#!/usr/bin/env python

import io
import os
import json

from google.cloud import speech
from google.cloud.speech import enums
from google.cloud.speech import types
from google.oauth2 import service_account

def VoiceToText(inputF,outputF,googlekey):

    #音声データの形式変換
    #wav形式→flac形式に変換
    cmd="sox "+ inputF + " --rate 16k --bits 16 --channels 1 " + outputF
    os.system(cmd) 

    #Googleの認証
    creds = service_account.Credentials.from_service_account_file(googlekey)
    if creds.requires_scopes:
        creds = creds.with_scopes(['https://www.googleapis.com/auth/cloud-platform'])

    #Cloud Speechのインスタンス生成
    sp = speech.SpeechClient(credentials=creds)

    #パラメターの準備
    with io.open(outputF, 'rb') as audio_file:
        content = audio_file.read()
        audio = types.RecognitionAudio(content=content)

    config = types.RecognitionConfig(
        encoding=enums.RecognitionConfig.AudioEncoding.FLAC,
        sample_rate_hertz=16000,
        language_code='ja')
    

    #Googleへリクエスト
    response = sp.recognize(config, audio)
    #print(response)

    if not response.results:
        print('データなし')
        nodata='データなし'
        return nodata
    else:        
        return response.results[0].alternatives[0].transcript    


if __name__ == '__main__':

    i_file='voice.wav'#元の音声データ
    o_file='voice.flac'#Google用の音声データ
    g_key='**************.json'#Google API keyを入力

    #テキスト化した音声データの取得
    txtVoice=VoiceToText(i_file,o_file,g_key)


